import * as React from 'react';
import { keycodeToName, specialChar } from './keycode';
const keycode = require('keycode');

export interface Props {
  onChange(keyboardInput: Array<number> | 'invalid'): void;
  keyboardInput: Array<number>
};

export interface State {
  invalid: boolean;
};

export default class KeycodeComponent extends React.Component<Props, State> {
  constructor(props: Props) {
    super(props);
  }

  public static defaultProps: Partial<Props> = {
    keyboardInput: []
  };

  handleKeyDown = (e: any) => {
    const {keyboardInput} = this.props;
    const {keyCode} = e;
    e.preventDefault();
    if (!keycode(keyCode)) {
      this.props.onChange('invalid');
    } else if (keyboardInput.indexOf(keyCode) === -1) {
      console.log(keyCode)
      let newKeyboardInput;
      // push specialChar to head
      if (specialChar.includes(keyCode)) {
        newKeyboardInput = [keyCode, ...keyboardInput];
      } else {
        newKeyboardInput = [...keyboardInput, keyCode];        
      }
      this.props.onChange(newKeyboardInput);
    }
  }

  render() {
    const {keyboardInput} = this.props;
    const val = keyboardInput.map(val => keycodeToName(val)).join('+');
    return (
      <div className="react-keycode-wrapper">
        <input type="text"
               className="react-keycode-input"
               value={val}
               onKeyDown={this.handleKeyDown}/>
      </div>
    );
  }
}
